@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -463,10 +463,10 @@ public class LdapContactStorage extends DefaultContactStorage {
 
     private static void updateMember(DistributionListEntryObject member, Contact referencedContact) throws OXException {
         if (referencedContact.containsObjectID()) {
-            member.setEntryID(referencedContact.getObjectID());
+            member.setEntryID(referencedContact.getId(true));
         }
         if (referencedContact.containsParentFolderID()) {
-            member.setFolderID(referencedContact.getParentFolderID());
+            member.setFolderID(referencedContact.getFolderId(true));
         }
         if (referencedContact.containsDisplayName()) {
             member.setDisplayname(referencedContact.getDisplayName());
