@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -45,6 +45,7 @@ import com.openexchange.groupware.container.Contact;
 import com.openexchange.groupware.container.DistributionListEntryObject;
 import com.openexchange.groupware.search.Order;
 import com.openexchange.groupware.tools.mappings.DefaultMapper;
+import com.openexchange.java.Strings;
 import com.openexchange.java.util.UUIDs;
 import com.openexchange.search.Operand;
 import com.openexchange.search.SingleSearchTerm;
@@ -257,7 +258,7 @@ public class LdapMapper extends DefaultMapper<Contact, ContactField> {
         }
 
         ldapMapping = (LdapMapping<?>)ldapMapping.clone();
-        String[] attributeNames = ldapAttribute.split(",");
+        String[] attributeNames = Strings.splitByComma(ldapAttribute);
         if (null ==  attributeNames || 0 == attributeNames.length) {
             throw LdapExceptionCodes.MISSING_CONFIG_VALUE.create(field);
         }
