@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -120,7 +120,7 @@ public abstract class LdapMapping<T> extends DefaultMapping<T, Contact> implemen
     }
 
     public String getLdapAttributeName(boolean suppressOptions) {
-        return null != ldapAttributeName && suppressOptions ? this.ldapAttributeName.split(";")[0] : this.ldapAttributeName;
+        return null != ldapAttributeName && suppressOptions ? Strings.splitBySemiColon(this.ldapAttributeName)[0] : this.ldapAttributeName;
     }
 
     public void setLdapAttributeName(String ldapAttributeName) {
